pitchtools.MelodicDiatonicIntervalSegment
=========================================

.. autoclass:: abjad.tools.pitchtools.MelodicDiatonicIntervalSegment
   :members:
   :undoc-members:
   :show-inheritance:
